==> mutt-0.48.1-h7.4.tgz: mutt-0.48.1-h7.4/mutt_menu.h <==
/* Copyright (C) 1996 Michael R. Elkins.
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * This file is named mutt_menu.h so it doesn't collide with ncurses'
 * menu.h
 */

#ifndef MUTT_MENU_H
#define MUTT_MENU_H

#include "toolbar.h"
#include "keymap.h"

typedef void entry_t (char *, int, int);

struct menu_t {
  char *title;        /* the title of this menu */
  short current;      /* current entry */
  short top;          /* entry that is the top of the current page */
  short redraw;
  short menu;         /* menu definition for keymap entries. */
  short max;          /* the number of entries in the menu */
  entry_t *makeEntry; /* function that generates line entries. */

  short oldcurrent;   /* for driver use only. */
};
typedef struct menu_t MUTTMENU;

#define REDRAW_FULL 1
#define REDRAW_INDEX 2
#define REDRAW_MOTION 3

MUTTMENU *mutt_newMenu (const char *);
void mutt_menuDestroy (MUTTMENU **);
int mutt_menuLoop (MUTTMENU *);

#endif /* MUTT_MENU_H */

==> mutt-0.56-h8.1.tgz: mutt-0.56-h8.1/mutt_menu.h <==
/*
 * Copyright (C) 1996 Michael R. Elkins <me@cs.hmc.edu>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * This file is named mutt_menu.h so it doesn't collide with ncurses menu.h
 */

typedef void entry_t (char *, int, size_t);

typedef struct menu_t {
  char *title;        /* the title of this menu */
  short current;      /* current entry */
  short redraw;
  short menu;         /* menu definition for keymap entries. */
  short max;          /* the number of entries in the menu */
  entry_t *makeEntry; /* function that generates line entries. */

  /* the following are used only by mutt_menuLoop() */
  short top;          /* entry that is the top of the current page */
  short pagelen;      /* number of entries per page */
  short oldcurrent;   /* for driver use only. */
} MUTTMENU;

enum {
  REDRAW_FULL = 1,
  REDRAW_INDEX,
  REDRAW_MOTION,
  REDRAW_CURRENT
};

MUTTMENU *mutt_newMenu (const char *);
void mutt_menuDestroy (MUTTMENU **);
int mutt_menuLoop (MUTTMENU *);
